@@ -118,6 +118,22 @@ def main():
         '--gearman', action='append', metavar='HOST:PORT', default=[],
         help='Gearman job servers'
     )
+    options.parser.add_argument(
+        '--gearman_keepalive', action="store_true",
+        help='use KEEPALIVE to Gearman server'
+    )
+    options.parser.add_argument(
+        '--gearman_keepcnt', type=int, metavar='COUNT',
+        help='max keepalive probes to send before killing connection'
+    )
+    options.parser.add_argument(
+        '--gearman_keepidle', type=int, metavar='SECONDS',
+        help='seconds of idle time before sending keepalive probes'
+    )
+    options.parser.add_argument(
+        '--gearman_keepintvl', type=int, metavar='SECONDS',
+        help='seconds between TCP keepalive probes'
+    )
     options.parser.add_argument(
         '--gearman_ssl_ca', metavar='FILE',
         help='Gearman SSL certificate authority'
@@ -131,8 +147,7 @@ def main():
         help='Gearman SSL key'
     )
     options.parser.add_argument(
-        '--gearman-poll',
-        dest='gearman_poll', type=int, metavar='TIME',
+        '--gearman_poll', type=int, metavar='TIME',
         default=1, help='Gearman worker polling timeout'
     )
     options.parser.add_argument(
@@ -140,6 +155,10 @@ def main():
         dest='threads', type=int, default=4,
         help='Number of worker threads to spawn'
     )
+    options.parser.add_argument(
+        '--rm_fip_ignore_500', action='store_true',
+        help='Ignore HTTP 500 error when removing a floating IP'
+    )
 
     args = options.run()
 
